#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dbus
version:              1.3.3
visibility:           public
id:                   dbus-1.3.3-bnrDL8oH3T1QWu0a1TxOj
key:                  dbus-1.3.3-bnrDL8oH3T1QWu0a1TxOj
license:              Apache-2.0
maintainer:           Andrey Sverdlichenko <blaze@rusty.zone>
author:               John Millikin <john@john-millikin.com>
stability:            experimental
homepage:             https://github.com/rblaze/haskell-dbus#readme
synopsis:             A client library for the D-Bus IPC system.
description:
    D-Bus is a simple, message-based protocol for inter-process
    communication, which allows applications to interact with other parts of
    the machine and the user'\''s session using remote procedure calls.

    D-Bus is a essential part of the modern Linux desktop, where it replaces
    earlier protocols such as CORBA and DCOP.

    This library is an implementation of the D-Bus protocol in Haskell. It
    can be used to add D-Bus support to Haskell applications, without the
    awkward interfaces common to foreign bindings.

    Example: connect to the session bus, and get a list of active names.

    @
    &#x7b;-\# LANGUAGE OverloadedStrings \#-&#x7d;

    import Data.List (sort)
    import DBus
    import DBus.Client

    main = do
    &#x20;   client <- connectSession
    &#x20;
    &#x20;   -- Request a list of connected clients from the bus
    &#x20;   reply <- call_ client (methodCall \"\/org\/freedesktop\/DBus\" \"org.freedesktop.DBus\" \"ListNames\")
    &#x20;       &#x7b; methodCallDestination = Just \"org.freedesktop.DBus\"
    &#x20;       &#x7d;
    &#x20;
    &#x20;   -- org.freedesktop.DBus.ListNames() returns a single value, which is
    &#x20;   -- a list of names (here represented as [String])
    &#x20;   let Just names = fromVariant (methodReturnBody reply !! 0)
    &#x20;
    &#x20;   -- Print each name on a line, sorted so reserved names are below
    &#x20;   -- temporary names.
    &#x20;   mapM_ putStrLn (sort names)
    @

    >$ ghc --make list-names.hs
    >$ ./list-names
    >:1.0
    >:1.1
    >:1.10
    >:1.106
    >:1.109
    >:1.110
    >ca.desrt.dconf
    >org.freedesktop.DBus
    >org.freedesktop.Notifications
    >org.freedesktop.secrets
    >org.gnome.ScreenSaver

category:             Network, Desktop
abi:                  102ae8e0b61a7ad405c4e9fd0a6934ab
exposed:              True
exposed-modules:
    DBus DBus.Client DBus.Generation DBus.Internal.Address
    DBus.Internal.Message DBus.Internal.Types DBus.Internal.Wire
    DBus.Introspection DBus.Introspection.Parse
    DBus.Introspection.Render DBus.Introspection.Types DBus.Socket
    DBus.TH DBus.Transport

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dbus-1.3.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dbus-1.3.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dbus-1.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dbus
hs-libraries:         HSdbus-1.3.3-bnrDL8oH3T1QWu0a1TxOj
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    conduit-1.3.6.1-bHMGfLNlzWFeFHMt1zPL0 containers-0.6.7
    deepseq-1.4.8.1 exceptions-0.10.7 filepath-1.4.300.1
    lens-5.3.4-GdOistvs0Ub2JwuPi3uyv5
    network-3.1.4.0-DnyUe3C7n48FET4frYkCJy parsec-3.1.16.1
    random-1.2.1.3-F4yImuU8Eln1YUMUzrSOOB
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 template-haskell-2.20.0.0
    text-2.0.2 th-lift-0.8.7-JMijAGUD56uaCh66C6Lgg transformers-0.6.1.0
    unix-2.8.4.0 vector-0.13.2.0-5aTe1V6fRGRBDLXlEcUVda
    xml-conduit-1.9.1.4-5NcvZLRcSVv2Y8J8pEe1P7
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau

haddock-interfaces:   /usr/share/doc/haskell-dbus/html/dbus.haddock
haddock-html:         /usr/share/doc/haskell-dbus/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

